@@ -20,7 +20,15 @@ class TimestampzToDatetimeUTC:
         return datetime.fromisoformat(value).replace(tzinfo=timezone.utc)
 
 
+class NumericToFloat:
+    @staticmethod
+    def convert(value):
+        return float(value)
+
+
 GRAPHQL_CONVERTERS = {
     'jsonb': JsonbToDict,
-    'timestamptz': TimestampzToAWSDateTime
+    'timestamptz': TimestampzToAWSDateTime,
+    'timestamp': TimestampzToAWSDateTime,
+    'numeric': NumericToFloat
 }
